#
# spec file for package fuse-exfat
#
# Copyright (c) 2023 SUSE LLC
# Copyright (c) 2013 Sidlovsky, Yaroslav <zawertun@gmail.com>
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           fuse-exfat
Version:        1.4.0
Release:        1.3
Summary:        exFAT file system implementation
License:        GPL-2.0-or-later
Group:          System/Filesystems
URL:            https://github.com/relan/exfat
Source0:        https://github.com/relan/exfat/releases/download/v%{version}/%{name}-%{version}.tar.gz
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  fuse-devel >= 2.6
BuildRequires:  libtool
BuildRequires:  pkgconfig
Requires:       fuse >= 2.6
Recommends:     exfat-utils

%description
This driver is an exFAT file system implementation with write
support. exFAT is a simple file system created by Microsoft. It is
intended to replace FAT32, removing some of its limitations. exFAT is
a standard FS for SDXC memory cards.

%prep
%setup -q

%build
# force installation of manual pages
sed -i -e 's/no-installman//' configure.ac
autoreconf -fiv
%configure
make %{?_smp_mflags}

%install
%make_install

%post
if ! grep -q -e '^exfat$' %{_sysconfdir}/filesystems ; then
    sed -i 's/*/exfat\n*/g' %{_sysconfdir}/filesystems
    echo "Added 'exfat' to the file %{_sysconfdir}/filesystems"
fi

if ! grep -q exfat_fuse %{_sysconfdir}/filesystems ; then
    sed -i 's/*/exfat_fuse\n*/g' %{_sysconfdir}/filesystems
    echo "Added 'exfat_fuse' to the file %{_sysconfdir}/filesystems"
fi

%postun
if [ "$1" = "0" ]; then
    sed -i -e '/exfat_fuse/d' -e '/^exfat$/d' %{_sysconfdir}/filesystems
    echo "Deleted 'exfat' and 'exfat_fuse' from the file %{_sysconfdir}/filesystems"
fi

%files
%license COPYING
%doc ChangeLog README
%{_sbindir}/mount.exfat
%{_sbindir}/mount.exfat-fuse
%{_mandir}/man8/mount.exfat-fuse.8%{?ext_man}

%changelog
* Fri Mar 17 2023 Dirk Müller <dmueller@suse.com>
- update to 1.4.0:
  * Added exfatattrib utility which prints or changes file
    attributes
  * Added FUSE 3 support. FUSE 2 continues to be supported.
  * Added support for timezone offsets
  * Fixed device opening error being reported as FS error.
  * Fixed possible data leakage when uninitialized clusters were
    allocated using NtSetInformationFile() call under Windows
    and FS was not unmounted correctly.
  * Improved compatibility with autoconf 2.70.
  * Allowed to specify the "nonempty" mount option.
  * Fixed file data contiguity handling bug which could cause
    performance degradation
  * Fixed possible crashes on invalid UTF-8 sequences.
  * Fixed a situation when FS could be erroneously marked as
    dirty (not cleanly unmounted).
* Mon Aug 15 2022 Dirk Müller <dmueller@suse.com>
- avoid bashism in post-scripts (bsc#1195391)
- remove usrmerge hacks
* Thu Nov 26 2020 Ludwig Nussel <lnussel@suse.de>
- prepare usrmerge (boo#1029961)
* Tue Dec 11 2018 Jan Engelhardt <jengelh@inai.de>
- Trim filler wording from description.
* Mon Dec 10 2018 astieger@suse.com
- fuse-exfat 1.3.0:
  * Clean up FUSE code preparing for FUSE 3 support
* Mon Dec 10 2018 astieger@suse.com
- fuse-exfat 1.2.8:
  * Fixed new files or directories creation in the root directory:
    ensure there are no 0x00 entries before valid ones; otherwise
    Windows can corrupt them boo#1118871
* Sat Aug 19 2017 asarai@suse.com
- Update to 1.2.7.
  * Fixed handling of two last clusters: operations with files that occupy these clusters could fail.
  * Fixed crash when started with stdin, stdout or stderr closed.
  [1.2.6]
  * Operations with directories (except initial listing) now make less read/write system calls.
  * Fixed handling of files with optional tail entries (0xe0-0xff): videoclip files created by Sony cameras were missing.
  * Write operations now correctly return ENOSPC (instead of EIO) when there is no free disk space left.
  * Fixed max file name length: it's 255 16-bit code units (not 256).
  [1.2.5]
  * Added an option for dumpexfat to show file fragments [Daniel Drake].
  * Fixed crash when directory starts with an invalid cluster.
  * Daylight saving time in now properly reflected in file timestamps.
* Sun Jun  5 2016 dap.darkness@gmail.com
- Update to 1.2.4:
  * Fixed wrong files names hashes.
  * Man pages are now installed by default.
  * Commas and backslashes in device names are now escaped.
* Sat Feb  6 2016 mpluskal@suse.com
- Provide symlinks to /sbin (see boo#965476)
* Sun Jan 17 2016 mpluskal@suse.com
- Update to 1.2.3
  * Fixed clusters loss when file renaming replaces target.
* Fri Dec 11 2015 mpluskal@suse.com
- Update to 1.2.2
  * Improved reliability in case of a sudden unplug: FS will be in
  a clean state after closing all files and performing sync(1).
  * Fixed compilation on Debian GNU/kFreeBSD and GNU/Hurd
  platforms.
  * Updated mount.exfat-fuse man page.
* Fri Oct  2 2015 malcolmlewis@opensuse.org
- Update to version 1.2.1:
  + Fixed compatibility with Zalman VE-200: now newly created
    directories do not have archive bit set.
  + Fixed heap corruption: malformed FS can use invalid sector or
    cluster size.
  + Fixed hang on mount: malformed FS can have cyclic references in
    the clusters.
* Tue Sep  1 2015 dsterba@suse.cz
- Update to version 1.2.0:
  * Switched from SCons to autotools.
  * Added musl libc support [Brendan Heading].
  * Worked around "FS is larger than device" error for memory cards
    formatted by Panasonic Lumix cameras.
  * Worked around "unknown entry type 0xe1" error for memory cards
    formatted by2 Sony cameras.
- spec: change upstream url, cleanup
* Tue Aug 19 2014 lars@linux-schulserver.de
- recommend exfat-utils
- specfile cleanup using spec-cleaner
- fix URL
- add Changelog and COPYING to doc files
* Tue Jul  8 2014 zawertun@gmail.com
- Update to version 1.1.0:
  + Relicensed the project from GPLv3+ to GPLv2+.
  + OpenBSD support [Helg Bredow].
  + Improved I/O errors handling.
  + Implemented fsync() and fsyncdir().
  + Fixed crash on Mac OS X 10.5 caused by non-standard use of
    realpath(). Also fixed TrueCrypt disks unmounting.
  + Avoid extra erase on writes to the end of a file. This should
    improve linear write speed.
  + Allow arbitrary changing of lower 9 bits of mode. Allow
    owner/group changing to the same owner/group. This fixes rsync.
  + Fixed buffers overflows when handling lengthy file names.
  + Fixed "real size does not equal to size" error on volumes with
    pagefile.sys.
  + Fixed negative IUsed in "df -i" output.
* Sun May 12 2013 subchaser1@gmail.com
- Fixed an error "unknown filesystem type 'exfat'" for the
  openSUSE 12.3
* Tue Mar 26 2013 zawertun@gmail.com
- Update to version 1.0.1:
  + Fixed unexpected removal of a directory if it is moved into
    itself.
  + Fixed "Operation not permitted" error on reading an empty file.
* Tue Jan 22 2013 zawertun@gmail.com
- Execute %%postun script part only after package uninstallation
* Tue Jan 22 2013 zawertun@gmail.com
- Added link from man page mount.exfat-fuse.8 to mount.exfat.8
* Mon Jan 21 2013 zawertun@gmail.com
- Update to version 1.0.0:
  + Fixed crash when renaming a file within a single directory and
    a new name differs only in case.
  + Fixed clusters allocation: a cluster beyond valid clusters
    range
    could be allocated.
  + Fixed crash when a volume is unmounted while some files are
    open.
  + SConscript now respects AR and RANLIB environment variables.
  + Improved error handling.
  + Enabled big_writes. This improves write speed (larger block
    size means less switches between kernel- and user-space).
  + Do BLKROGET ioctl to make sure the device is not read-only:
    after "blockdev --setro" kernel still allows to open the device
    in read-write mode but fails writes.
* Sun Jan 13 2013 zawertun@gmail.css
- %%{optflags} passed as the value for CCFLAGS and CPPFLAGS
* Thu Sep 20 2012 zawertun@gmail.com
- Update to version 0.9.8:
  + The mkfs utility can now create huge file systems (up to several
    exabytes).
  + Fixed handling of characters beyond Basic Multilingual Plane.
  + Echo messages to syslog only if stderr is not connected to a
    terminal.
* Sat May  5 2012 zawertun@gmail.com
- Update to version 0.9.7:
  + Out-of-the-box FreeBSD support (via ublio library).
  + Fixed "missing EOD entry" error (could happen while reading
    directory that consists of several clusters).
  + Fixed interpretation of minutes field in files timestamps
    (minutes could be displayed incorrectly).
  + Fixed mtime seconds field initialization for newly created file
    (mtime could be 1 sec less than creation time).
  + SConscript now respects CC, CCFLAGS and LDFLAGS environment
    variables.
* Tue Jan 17 2012 zawertun@gmail.com
- Update to version 0.9.6:
  + Fixed write performance regression introduced in 0.9.4.
  + Mount in read-only mode if the device is write-protected.
  + Set ctime to mtime to ensure we don't break programs that rely on ctime
    (e.g. rsync considered that all files are outdated) [Eldad Zack].
  + Indicate that FS in not clean when it was not cleanly unmounted.
  + Utilities are now compatible with GNU/Hurd.
  + Fixed several memory leaks that could occur on error handling paths.
  + Improved handling of corrupted file systems.
* Mon Jun  6 2011 zawertun@gmail.com
- Update to version 0.9.5:
  + Fixed erasing of the root directory cluster when creating a new FS with mkexfatfs. This bug could cause mkexfatfs to produce invalid FS.
  + Utilities are not linked with libfuse anymore.
  + Ensure that the path being opened is either a device or a regular file.
